@@ -18,15 +18,17 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 # USA.
 from PyQt5.QtCore import QObject
+
 from picard import config
-from picard.plugin import PluginFunctions, PluginPriority
-from picard.similarity import similarity2
-from picard.util import (
-    linear_combination_of_weights,
-)
-from picard.util.tags import PRESERVED_TAGS
 from picard.mbjson import artist_credit_from_node
+from picard.plugin import (
+    PluginFunctions,
+    PluginPriority,
+)
+from picard.similarity import similarity2
+from picard.util import linear_combination_of_weights
 from picard.util.imagelist import ImageList
+from picard.util.tags import PRESERVED_TAGS
 
 MULTI_VALUED_JOINER = '; '
 
@@ -60,6 +62,7 @@ class Metadata(dict):
     def __init__(self):
         super().__init__()
         self.images = ImageList()
+        self.has_common_images = True
         self.deleted_tags = set()
         self.length = 0
 
@@ -123,7 +126,9 @@ class Metadata(dict):
                 else:
                     score = similarity2(a, b)
                 parts.append((score, weight))
-
+            elif (a and name in other.deleted_tags
+                  or b and name in self.deleted_tags):
+                parts.append((0, weight))
         return linear_combination_of_weights(parts)
 
     def compare_to_release(self, release, weights):
@@ -220,12 +225,13 @@ class Metadata(dict):
 
         if 'title' in self:
             a = self['title']
-            b = track['title']
+            b = track.get('title', '')
             parts.append((similarity2(a, b), weights["title"]))
 
         if 'artist' in self:
             a = self['artist']
-            b = artist_credit_from_node(track['artist-credit'])[0]
+            artist_credits = track.get('artist-credit', [])
+            b = artist_credit_from_node(artist_credits)[0]
             parts.append((similarity2(a, b), weights["artist"]))
 
         a = self.length
@@ -273,6 +279,9 @@ class Metadata(dict):
         super().clear()
         self.images = ImageList()
         self.length = 0
+        self.clear_deleted()
+
+    def clear_deleted(self):
         self.deleted_tags = set()
 
     def getall(self, name):
@@ -296,10 +305,10 @@ class Metadata(dict):
     def __setitem__(self, name, values):
         if not isinstance(values, list):
             values = [values]
-        values = [string_(value) for value in values if value]
+        values = [str(value) for value in values if value]
         if len(values):
             self.set(name, values)
-        else:
+        elif name in self:
             self.delete(name)
 
     def add(self, name, value):
